@@ -52,10 +52,11 @@ int RS_XML(parseWithParserData)(FILE *file, RS_XMLParserData *parserData)
     size_t len = fread(buf, 1, sizeof(buf), file);
     done = len < sizeof(buf);
     if (!XML_Parse(parser, buf, len, done)) {
-      fprintf(stderr,
+      PROBLEM 
 	      "%s at line %d\n",
 	      XML_ErrorString(XML_GetErrorCode(parser)),
-	      XML_GetCurrentLineNumber(parser));
+   	      XML_GetCurrentLineNumber(parser)
+        WARN;
       return 1;
     }
   } while (!done);
